.. _usage:

Usage examples
==============

We are mainly using `pandas` and `geopandas` here to be able to plot the geometries, but most non-geometry features are available
in the other APIs as well.

.. note::

    These examples are supposed to show some of the provided functionalities. They certainly do not cover all aspects.

.. toctree::
    :maxdepth: 2

    raster
    vector
    grid
